
# OpenVoiceOS Bus Client

This module is a simple interface for the mycroft messagebus and can be used to connect to ovos, send messages and react to messages sent by the OpenVoiceOS system.

This module extends the mycroft-messagebus-client with a Session implementation
